@@ -3,9 +3,6 @@ package SVN::Hooks::Notify;
 use strict;
 use warnings;
 use SVN::Hooks;
-use Email::Send;
-use Email::Simple;
-use Email::Simple::Creator;
 
 use Exporter qw/import/;
 my $HOOK = 'NOTIFY';
@@ -146,7 +143,7 @@ L<http://search.cpan.org/dist/SVN-Hooks>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2009 CPqD, all rights reserved.
+Copyright 2008-2011 CPqD, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
